There are some important areas you can contribute to this project:

## Code
* Have better visuals during checking connection.
* Check bridges syntax based on bridge type.
* Ideally create `AdwAboutWindow` [using AppStream metadata](https://gnome.pages.gitlab.gnome.org/libadwaita/doc/main/ctor.AboutWindow.new_from_appdata.html).
* Move SaveButton click logic to actions.

## Community
* Improvement in Pypi release to support desktop-related issues better.
* Making native package build recepies for more GNU/Linux distros.
* Releasing on Flathub and moving it to GNOME Circle.
